#!/bin/bash

# Copyright (c) 2003 Christian T. Steigies
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

find /home -name .circuslinux -print0 | \
xargs -0 perl /usr/share/doc/circuslinux/merge_scorefiles.pl 

chown root.games /var/games/circuslinux/scorefile
chmod 664 /var/games/circuslinux/scorefile
